/* MIT shared memory extention */
#undef HAVE_MITSHM

/* jpeg lib */
#undef HAVE_LIBJPEG

/* lirc lib */
#undef HAVE_LIBLIRC_CLIENT
